# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1.10.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six



class V1beta1JSONSchemaPropsOrStringArray(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_property': 'list[str]',
        'schema': 'V1beta1JSONSchemaProps'
    }

    attribute_map = {
        '_property': 'Property',
        'schema': 'Schema'
    }

    def __init__(self, _property=None, schema=None):  # noqa: E501
        """V1beta1JSONSchemaPropsOrStringArray - a model defined in Swagger"""  # noqa: E501

        self.__property = None
        self._schema = None
        self.discriminator = None

        self._property = _property
        self.schema = schema

    @property
    def _property(self):
        """Gets the _property of this V1beta1JSONSchemaPropsOrStringArray.  # noqa: E501


        :return: The _property of this V1beta1JSONSchemaPropsOrStringArray.  # noqa: E501
        :rtype: list[str]
        """
        return self.__property

    @_property.setter
    def _property(self, _property):
        """Sets the _property of this V1beta1JSONSchemaPropsOrStringArray.


        :param _property: The _property of this V1beta1JSONSchemaPropsOrStringArray.  # noqa: E501
        :type: list[str]
        """
        if _property is None:
            raise ValueError("Invalid value for `_property`, must not be `None`")  # noqa: E501

        self.__property = _property

    @property
    def schema(self):
        """Gets the schema of this V1beta1JSONSchemaPropsOrStringArray.  # noqa: E501


        :return: The schema of this V1beta1JSONSchemaPropsOrStringArray.  # noqa: E501
        :rtype: V1beta1JSONSchemaProps
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """Sets the schema of this V1beta1JSONSchemaPropsOrStringArray.


        :param schema: The schema of this V1beta1JSONSchemaPropsOrStringArray.  # noqa: E501
        :type: V1beta1JSONSchemaProps
        """
        if schema is None:
            raise ValueError("Invalid value for `schema`, must not be `None`")  # noqa: E501

        self._schema = schema

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1JSONSchemaPropsOrStringArray):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
